@@ -61,13 +61,10 @@ impl CacheServer {
         .unwrap();
         let maybe_import_map_resolver =
           maybe_import_map.map(ImportMapResolver::new);
-        let maybe_jsx_resolver = maybe_config_file
-          .as_ref()
-          .map(|cf| {
-            cf.to_maybe_jsx_import_source_module()
-              .map(|im| JsxResolver::new(im, maybe_import_map_resolver.clone()))
-          })
-          .flatten();
+        let maybe_jsx_resolver = maybe_config_file.as_ref().and_then(|cf| {
+          cf.to_maybe_jsx_import_source_module()
+            .map(|im| JsxResolver::new(im, maybe_import_map_resolver.clone()))
+        });
         let maybe_resolver = if maybe_jsx_resolver.is_some() {
           maybe_jsx_resolver.as_ref().map(|jr| jr.as_resolver())
         } else {
@@ -76,8 +73,7 @@ impl CacheServer {
             .map(|im| im.as_resolver())
         };
         let maybe_imports = maybe_config_file
-          .map(|cf| cf.to_maybe_imports().ok())
-          .flatten()
+          .and_then(|cf| cf.to_maybe_imports().ok())
           .flatten();
         let mut cache = FetchCacher::new(
           ps.dir.gen_cache.clone(),
@@ -187,10 +183,9 @@ impl CacheMetadata {
     let version = self
       .cache
       .get_cache_filename(specifier)
-      .map(|ref path| calculate_fs_version(path))
-      .flatten();
+      .and_then(|ref path| calculate_fs_version(path));
     let metadata = self.metadata.lock().get(specifier).cloned();
-    if metadata.as_ref().map(|m| m.version.clone()).flatten() != version {
+    if metadata.as_ref().and_then(|m| m.version.clone()) != version {
       self.refresh(specifier).map(|m| m.values)
     } else {
       metadata.map(|m| m.values)
