@@ -84,6 +84,8 @@ mod run;
 mod test;
 #[path = "upgrade_tests.rs"]
 mod upgrade;
+#[path = "vendor_tests.rs"]
+mod vendor;
 #[path = "watcher_tests.rs"]
 mod watcher;
 #[path = "worker_tests.rs"]
@@ -758,7 +760,7 @@ fn websocket_server_idletimeout() {
   assert_eq!(msg, "READY");
 
   let req = http::request::Builder::new()
-    .uri("ws://localhost:4502")
+    .uri("ws://localhost:4509")
     .body(())
     .unwrap();
   let (_ws, _request) =
@@ -1140,6 +1142,7 @@ fn js_unit_tests() {
     .arg("test")
     .arg("--unstable")
     .arg("--location=http://js-unit-tests/foo/bar")
+    .arg("--no-prompt")
     .arg("-A")
     .arg(util::tests_path().join("unit"))
     .spawn()
